pub trait PreNormalization<I: Iterator<Item = char>> {
// Required methods
fn categorize(
self,
error: Rc<RefCell<Option<BasicTextError>>>,
) -> Categorize<I> ⓘ;
fn isolate_unassigned(self) -> IsolateUnassigned<I> ⓘ;
}Expand description
An extension crate providing iterator transforms useful before normalization.
Required Methods
Sourcefn categorize(self, error: Rc<RefCell<Option<BasicTextError>>>) -> Categorize<I> ⓘ
fn categorize(self, error: Rc<RefCell<Option<BasicTextError>>>) -> Categorize<I> ⓘ
Return an iterator which detects some sequences which are not valid in Basic Text.
Sourcefn isolate_unassigned(self) -> IsolateUnassigned<I> ⓘ
fn isolate_unassigned(self) -> IsolateUnassigned<I> ⓘ
Return an iterator that inserts CGJs around unassigned scalar values to protect them from future normalization.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".